from ckiptagger.api import construct_dictionary
from ckiptagger.api import WS
from ckiptagger.api import POS
from ckiptagger.api import NER
from ckiptagger import data_utils

import logging
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
logging.warn("'ckipneutools' is DEPRECATED, please shift to install and import 'ckiptagger'")
